==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-extension-bundles/nifi-standard-services/nifi-oauth2-provider-api/src/test/java/org/apache/nifi/oauth2/AccessTokenTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.oauth2;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.time.Instant;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class AccessTokenTest {
    private static final long FIVE_MINUTES_AGO = -300;

    private static final long IN_FIVE_MINUTES = 300;

    private Instant now;

    @BeforeEach
    void setUp() {
        now = Instant.now();
    }

    @Test
    public void testIsExpiredFiveMinutesAgo() {
        final AccessToken accessToken = getAccessToken(FIVE_MINUTES_AGO);

        assertTrue(accessToken.isExpired());
    }

    @Test
    public void testIsExpiredInFiveMinutes() {
        final AccessToken accessToken = getAccessToken(IN_FIVE_MINUTES);

        assertFalse(accessToken.isExpired());
    }

    private AccessToken getAccessToken(final long expiresInSeconds) {
        return new AccessToken(
                null,
                null,
                null,
                expiresInSeconds,
                null
        ) {
            @Override
            protected Instant now() {
                return now;
            }
        };
    }
}

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-extension-bundles/nifi-standard-services/nifi-oauth2-provider-api/src/test/java/org/apache/nifi/oauth2/AccessTokenTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.oauth2;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.time.Instant;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class AccessTokenTest {
    private static final long FIVE_MINUTES_AGO = -300;

    private static final long IN_FIVE_MINUTES = 300;

    private Instant now;

    @BeforeEach
    void setUp() {
        now = Instant.now();
    }

    @Test
    public void testIsExpiredFiveMinutesAgo() {
        final AccessToken accessToken = getAccessToken(FIVE_MINUTES_AGO);

        assertTrue(accessToken.isExpired());
    }

    @Test
    public void testIsExpiredInFiveMinutes() {
        final AccessToken accessToken = getAccessToken(IN_FIVE_MINUTES);

        assertFalse(accessToken.isExpired());
    }

    @Test
    public void testIsExpiredNever() {
        final AccessToken accessToken = getAccessToken(null);

        assertFalse(accessToken.isExpired());
    }

    private AccessToken getAccessToken(final Long expiresInSeconds) {
        return new AccessToken(
                null,
                null,
                null,
                expiresInSeconds,
                null
        ) {
            @Override
            protected Instant now() {
                return now;
            }
        };
    }
}
